from __future__ import print_function

__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

import unittest

from nonefield.tests.test_nonefield import *

if __name__ == '__main__':
    unittest.main()
