__title__ = 'nonefield.tests.constants'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'CHANGED_NONEFIELD_VALUE',
    'ENDPOINT_URL',
    'INITIAL_NONEFIELD_VALUE',
)

ENDPOINT_URL = "http://example.com"
INITIAL_NONEFIELD_VALUE = "Lorem ipsum"
CHANGED_NONEFIELD_VALUE = "Dolor sit amet"
